==> certmanager-model-v1beta1-6.6.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/CertificateDNSNameSelectorFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface CertificateDNSNameSelectorFluent<A extends CertificateDNSNameSelectorFluent<A>> extends Fluent<A>{
  public A addToDnsNames(Integer index,String item);
  public A setToDnsNames(Integer index,String item);
  public A addToDnsNames(java.lang.String... items);
  public A addAllToDnsNames(Collection<String> items);
  public A removeFromDnsNames(java.lang.String... items);
  public A removeAllFromDnsNames(Collection<String> items);
  public List<String> getDnsNames();
  public String getDnsName(Integer index);
  public String getFirstDnsName();
  public String getLastDnsName();
  public String getMatchingDnsName(Predicate<String> predicate);
  public Boolean hasMatchingDnsName(Predicate<String> predicate);
  public A withDnsNames(List<String> dnsNames);
  public A withDnsNames(java.lang.String... dnsNames);
  public Boolean hasDnsNames();
  public A addToDnsZones(Integer index,String item);
  public A setToDnsZones(Integer index,String item);
  public A addToDnsZones(java.lang.String... items);
  public A addAllToDnsZones(Collection<String> items);
  public A removeFromDnsZones(java.lang.String... items);
  public A removeAllFromDnsZones(Collection<String> items);
  public List<String> getDnsZones();
  public String getDnsZone(Integer index);
  public String getFirstDnsZone();
  public String getLastDnsZone();
  public String getMatchingDnsZone(Predicate<String> predicate);
  public Boolean hasMatchingDnsZone(Predicate<String> predicate);
  public A withDnsZones(List<String> dnsZones);
  public A withDnsZones(java.lang.String... dnsZones);
  public Boolean hasDnsZones();
  public A addToMatchLabels(String key,String value);
  public A addToMatchLabels(Map<String,String> map);
  public A removeFromMatchLabels(String key);
  public A removeFromMatchLabels(Map<String,String> map);
  public Map<String,String> getMatchLabels();
  public <K,V>A withMatchLabels(Map<String,String> matchLabels);
  public Boolean hasMatchLabels();
  
}

==> certmanager-model-v1beta1-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/CertificateDNSNameSelectorFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface CertificateDNSNameSelectorFluent<A extends CertificateDNSNameSelectorFluent<A>> extends Fluent<A>{
  public A addToDnsNames(int index,String item);
  public A setToDnsNames(int index,String item);
  public A addToDnsNames(java.lang.String... items);
  public A addAllToDnsNames(Collection<String> items);
  public A removeFromDnsNames(java.lang.String... items);
  public A removeAllFromDnsNames(Collection<String> items);
  public List<String> getDnsNames();
  public String getDnsName(int index);
  public String getFirstDnsName();
  public String getLastDnsName();
  public String getMatchingDnsName(Predicate<String> predicate);
  public Boolean hasMatchingDnsName(Predicate<String> predicate);
  public A withDnsNames(List<String> dnsNames);
  public A withDnsNames(java.lang.String... dnsNames);
  public Boolean hasDnsNames();
  public A addToDnsZones(int index,String item);
  public A setToDnsZones(int index,String item);
  public A addToDnsZones(java.lang.String... items);
  public A addAllToDnsZones(Collection<String> items);
  public A removeFromDnsZones(java.lang.String... items);
  public A removeAllFromDnsZones(Collection<String> items);
  public List<String> getDnsZones();
  public String getDnsZone(int index);
  public String getFirstDnsZone();
  public String getLastDnsZone();
  public String getMatchingDnsZone(Predicate<String> predicate);
  public Boolean hasMatchingDnsZone(Predicate<String> predicate);
  public A withDnsZones(List<String> dnsZones);
  public A withDnsZones(java.lang.String... dnsZones);
  public Boolean hasDnsZones();
  public A addToMatchLabels(String key,String value);
  public A addToMatchLabels(Map<String,String> map);
  public A removeFromMatchLabels(String key);
  public A removeFromMatchLabels(Map<String,String> map);
  public Map<String,String> getMatchLabels();
  public <K,V>A withMatchLabels(Map<String,String> matchLabels);
  public Boolean hasMatchLabels();
  
}
